@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2020, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -20,24 +20,22 @@
 
 #include <sundials/sundials_nvector.h>
 
-#ifdef __cplusplus  /* wrapper to enable C++ usage */
+#ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
 #endif
 
+/* BandPrec initialization function */
 
-/* BandPrec inititialization function */
-
-SUNDIALS_EXPORT int ARKBandPrecInit(void *arkode_mem, sunindextype N,
+SUNDIALS_EXPORT int ARKBandPrecInit(void* arkode_mem, sunindextype N,
                                     sunindextype mu, sunindextype ml);
 
 /* Optional output functions */
-
-SUNDIALS_EXPORT int ARKBandPrecGetWorkSpace(void *arkode_mem,
-                                            long int *lenrwLS,
-                                            long int *leniwLS);
-SUNDIALS_EXPORT int ARKBandPrecGetNumRhsEvals(void *arkode_mem,
-                                              long int *nfevalsBP);
-
+SUNDIALS_DEPRECATED_EXPORT_MSG(
+  "Work space functions will be removed in version 8.0.0")
+int ARKBandPrecGetWorkSpace(void* arkode_mem, long int* lenrwLS,
+                            long int* leniwLS);
+SUNDIALS_EXPORT int ARKBandPrecGetNumRhsEvals(void* arkode_mem,
+                                              long int* nfevalsBP);
 
 #ifdef __cplusplus
 }
