@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -45,11 +45,9 @@
 #if defined(SUNDIALS_EXTENDED_PRECISION)
 #define GSYM "Lg"
 #define ESYM "Le"
-#define FSYM "Lf"
 #else
 #define GSYM "g"
 #define ESYM "e"
-#define FSYM "f"
 #endif
 
 /* User-supplied Functions Called by the Solver */
@@ -120,32 +118,32 @@ int main(void)
   N_VConst(ONE, constraints);
 
   /* Call ARKStepCreate to initialize the ARK timestepper module and
-     specify the right-hand side function in y'=f(t,y), the inital time
+     specify the right-hand side function in y'=f(t,y), the initial time
      T0, and the initial dependent variable vector y.  Note: since this
      problem is fully implicit, we set f_E to NULL and f_I to f. */
   arkode_mem = ARKStepCreate(NULL, f, T0, y, ctx);
   if (check_flag((void*)arkode_mem, "ARKStepCreate", 0)) { return 1; }
 
   /* Set routines */
-  flag = ARKStepSetInitStep(arkode_mem, h0); /* Set custom initial step */
-  if (check_flag(&flag, "ARKStepSetInitStep", 1)) { return 1; }
-  flag = ARKStepSetMaxErrTestFails(arkode_mem,
-                                   20); /* Increase max error test fails */
-  if (check_flag(&flag, "ARKStepSetMaxErrTestFails", 1)) { return 1; }
-  flag = ARKStepSetMaxNonlinIters(arkode_mem, 8); /* Increase max nonlin iters  */
-  if (check_flag(&flag, "ARKStepSetMaxNonlinIters", 1)) { return 1; }
-  flag = ARKStepSetNonlinConvCoef(arkode_mem,
-                                  SUN_RCONST(1.e-7)); /* Set nonlinear convergence coeff. */
-  if (check_flag(&flag, "ARKStepSetNonlinConvCoef", 1)) { return 1; }
-  flag = ARKStepSetMaxNumSteps(arkode_mem, 100000); /* Increase max num steps */
-  if (check_flag(&flag, "ARKStepSetMaxNumSteps", 1)) { return 1; }
-  flag = ARKStepSetPredictorMethod(arkode_mem,
-                                   1); /* Specify maximum-order predictor */
-  if (check_flag(&flag, "ARKStepSetPredictorMethod", 1)) { return 1; }
-  flag = ARKStepSStolerances(arkode_mem, reltol, abstol); /* Specify tolerances */
-  if (check_flag(&flag, "ARKStepSStolerances", 1)) { return 1; }
-  flag = ARKStepSetConstraints(arkode_mem, constraints); /* Set constraints */
-  if (check_flag(&flag, "ARKStepSetConstraints", 1)) { return 1; }
+  flag = ARKodeSetInitStep(arkode_mem, h0); /* Set custom initial step */
+  if (check_flag(&flag, "ARKodeSetInitStep", 1)) { return 1; }
+  flag = ARKodeSetMaxErrTestFails(arkode_mem,
+                                  20); /* Increase max error test fails */
+  if (check_flag(&flag, "ARKodeSetMaxErrTestFails", 1)) { return 1; }
+  flag = ARKodeSetMaxNonlinIters(arkode_mem, 8); /* Increase max nonlin iters  */
+  if (check_flag(&flag, "ARKodeSetMaxNonlinIters", 1)) { return 1; }
+  flag = ARKodeSetNonlinConvCoef(arkode_mem,
+                                 SUN_RCONST(1.e-7)); /* Set nonlinear convergence coeff. */
+  if (check_flag(&flag, "ARKodeSetNonlinConvCoef", 1)) { return 1; }
+  flag = ARKodeSetMaxNumSteps(arkode_mem, 100000); /* Increase max num steps */
+  if (check_flag(&flag, "ARKodeSetMaxNumSteps", 1)) { return 1; }
+  flag = ARKodeSetPredictorMethod(arkode_mem,
+                                  1); /* Specify maximum-order predictor */
+  if (check_flag(&flag, "ARKodeSetPredictorMethod", 1)) { return 1; }
+  flag = ARKodeSStolerances(arkode_mem, reltol, abstol); /* Specify tolerances */
+  if (check_flag(&flag, "ARKodeSStolerances", 1)) { return 1; }
+  flag = ARKodeSetConstraints(arkode_mem, constraints); /* Set constraints */
+  if (check_flag(&flag, "ARKodeSetConstraints", 1)) { return 1; }
 
   /* Initialize dense matrix data structure and solver */
   A = SUNDenseMatrix(NEQ, NEQ, ctx);
@@ -154,11 +152,11 @@ int main(void)
   if (check_flag((void*)LS, "SUNLinSol_Dense", 0)) { return 1; }
 
   /* Linear solver interface */
-  flag = ARKStepSetLinearSolver(arkode_mem, LS,
-                                A); /* Attach matrix and linear solver */
-  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) { return 1; }
-  flag = ARKStepSetJacFn(arkode_mem, Jac); /* Set the Jacobian routine */
-  if (check_flag(&flag, "ARKStepSetJacFn", 1)) { return 1; }
+  flag = ARKodeSetLinearSolver(arkode_mem, LS,
+                               A); /* Attach matrix and linear solver */
+  if (check_flag(&flag, "ARKodeSetLinearSolver", 1)) { return 1; }
+  flag = ARKodeSetJacFn(arkode_mem, Jac); /* Set the Jacobian routine */
+  if (check_flag(&flag, "ARKodeSetJacFn", 1)) { return 1; }
 
   /* Open output stream for results, output comment line */
   UFID = fopen("solution.txt", "w");
@@ -168,7 +166,7 @@ int main(void)
   fprintf(UFID, " %.16" ESYM " %.16" ESYM " %.16" ESYM " %.16" ESYM "\n", T0,
           NV_Ith_S(y, 0), NV_Ith_S(y, 1), NV_Ith_S(y, 2));
 
-  /* Main time-stepping loop: calls ARKStepEvolve to perform the integration, then
+  /* Main time-stepping loop: calls ARKodeEvolve to perform the integration, then
      prints results.  Stops when the final time has been reached */
   t    = T0;
   tout = T0 + dTout;
@@ -178,8 +176,8 @@ int main(void)
          NV_Ith_S(y, 0), NV_Ith_S(y, 1), NV_Ith_S(y, 2));
   for (iout = 0; iout < Nt; iout++)
   {
-    flag = ARKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL); /* call integrator */
-    if (check_flag(&flag, "ARKStepEvolve", 1)) { break; }
+    flag = ARKodeEvolve(arkode_mem, tout, y, &t, ARK_NORMAL); /* call integrator */
+    if (check_flag(&flag, "ARKodeEvolve", 1)) { break; }
     printf("  %10.3" ESYM "  %12.5" ESYM "  %12.5" ESYM "  %12.5" ESYM
            "\n", /* access/print solution */
            t, NV_Ith_S(y, 0), NV_Ith_S(y, 1), NV_Ith_S(y, 2));
@@ -200,28 +198,30 @@ int main(void)
   fclose(UFID);
 
   /* Print some final statistics */
-  flag = ARKStepGetNumSteps(arkode_mem, &nst);
-  check_flag(&flag, "ARKStepGetNumSteps", 1);
-  flag = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
-  check_flag(&flag, "ARKStepGetNumStepAttempts", 1);
-  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  check_flag(&flag, "ARKStepGetNumRhsEvals", 1);
-  flag = ARKStepGetNumLinSolvSetups(arkode_mem, &nsetups);
-  check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1);
-  flag = ARKStepGetNumErrTestFails(arkode_mem, &netf);
-  check_flag(&flag, "ARKStepGetNumErrTestFails", 1);
-  flag = ARKStepGetNumStepSolveFails(arkode_mem, &ncfn);
-  check_flag(&flag, "ARKStepGetNumStepSolveFails", 1);
-  flag = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
-  check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1);
-  flag = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &nnf);
-  check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1);
-  flag = ARKStepGetNumJacEvals(arkode_mem, &nje);
-  check_flag(&flag, "ARKStepGetNumJacEvals", 1);
-  flag = ARKStepGetNumLinRhsEvals(arkode_mem, &nfeLS);
-  check_flag(&flag, "ARKStepGetNumLinRhsEvals", 1);
-  flag = ARKStepGetNumConstrFails(arkode_mem, &nctf);
-  check_flag(&flag, "ARKStepGetNumConstrFails", 1);
+  flag = ARKodeGetNumSteps(arkode_mem, &nst);
+  check_flag(&flag, "ARKodeGetNumSteps", 1);
+  flag = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
+  check_flag(&flag, "ARKodeGetNumStepAttempts", 1);
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  check_flag(&flag, "ARKodeGetNumRhsEvals", 1);
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  check_flag(&flag, "ARKodeGetNumRhsEvals", 1);
+  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
+  check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1);
+  flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
+  check_flag(&flag, "ARKodeGetNumErrTestFails", 1);
+  flag = ARKodeGetNumStepSolveFails(arkode_mem, &ncfn);
+  check_flag(&flag, "ARKodeGetNumStepSolveFails", 1);
+  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
+  check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1);
+  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &nnf);
+  check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1);
+  flag = ARKodeGetNumJacEvals(arkode_mem, &nje);
+  check_flag(&flag, "ARKodeGetNumJacEvals", 1);
+  flag = ARKodeGetNumLinRhsEvals(arkode_mem, &nfeLS);
+  check_flag(&flag, "ARKodeGetNumLinRhsEvals", 1);
+  flag = ARKodeGetNumConstrFails(arkode_mem, &nctf);
+  check_flag(&flag, "ARKodeGetNumConstrFails", 1);
 
   printf("\nFinal Solver Statistics:\n");
   printf("   Internal solver steps = %li (attempted = %li)\n", nst, nst_a);
@@ -239,12 +239,12 @@ int main(void)
   flag = check_ans(y, t, reltol, abstol);
 
   /* Clean up and return with successful completion */
-  N_VDestroy(y);            /* Free y vector */
-  N_VDestroy(constraints);  /* Free constraints vector */
-  ARKStepFree(&arkode_mem); /* Free integrator memory */
-  SUNLinSolFree(LS);        /* Free linear solver */
-  SUNMatDestroy(A);         /* Free A matrix */
-  SUNContext_Free(&ctx);    /* Free context */
+  N_VDestroy(y);           /* Free y vector */
+  N_VDestroy(constraints); /* Free constraints vector */
+  ARKodeFree(&arkode_mem); /* Free integrator memory */
+  SUNLinSolFree(LS);       /* Free linear solver */
+  SUNMatDestroy(A);        /* Free A matrix */
+  SUNContext_Free(&ctx);   /* Free context */
 
   return flag;
 }
@@ -338,7 +338,7 @@ static int check_flag(void* flagvalue, const char* funcname, int opt)
 }
 
 /* compare the solution at the final time 1e11s to a reference solution computed
-   using a relative tolerance of 1e-8 and absoltue tolerance of 1e-14 */
+   using a relative tolerance of 1e-8 and absolute tolerance of 1e-14 */
 static int check_ans(N_Vector y, sunrealtype t, sunrealtype rtol, sunrealtype atol)
 {
   int passfail = 0; /* answer pass (0) or fail (1) flag */
