@@ -3,23 +3,19 @@
  * Programmer(s): Daniel R. Reynolds and Ting Yan @ SMU
  *      Based on idaFoodWeb_bnd.c and parallelized with OpenMP
  * -----------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * Example program for IDAS: Food web problem.
  *
- * This example program (OpenMP version) uses the SUNBAND linear 
+ * This example program (OpenMP version) uses the SUNBAND linear
  * solver, and IDACalcIC for initial condition calculation.
  *
  * The mathematical problem solved in this example is a DAE system
@@ -76,19 +72,19 @@
  * The DAE system is solved by IDAS using the SUNBAND linear solver.
  * Output is printed at t = 0, .001, .01, .1, .4, .7, 1.
  *
- * Optionally, we can set the number of threads from environment 
+ * Optionally, we can set the number of threads from environment
  * variable or command line. To check the current value for number
  * of threads from environment:
  *      % echo $OMP_NUM_THREADS
  *
  * Execution:
  *
- * To use the default value for the number of threads from 
+ * To use the default value for the number of threads from
  * the OMP_NUM_THREADS environment value:
- *      % ./idasFoodWeb_bnd_omp 
+ *      % ./idasFoodWeb_bnd_omp
  * To specify the number of threads at the command line, use
  *      % ./idasFoodWeb_bnd_omp num_threads
- * where num_threads is the desired number of threads. 
+ * where num_threads is the desired number of threads.
  *
  * -----------------------------------------------------------------
  * References:
@@ -109,16 +105,15 @@
  * -----------------------------------------------------------------
  */
 
+#include <idas/idas.h>
+#include <math.h>
+#include <nvector/nvector_openmp.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <math.h>
-
-#include <idas/idas.h>
-#include <sunmatrix/sunmatrix_band.h>
-#include <sunlinsol/sunlinsol_band.h>
-#include <nvector/nvector_openmp.h>
 #include <sundials/sundials_direct.h>
 #include <sundials/sundials_types.h>
+#include <sunlinsol/sunlinsol_band.h>
+#include <sunmatrix/sunmatrix_band.h>
 
 #ifdef _OPENMP
 #include <omp.h>
@@ -126,72 +121,75 @@
 
 /* Problem Constants. */
 
-#define NPREY       1              /* No. of prey (= no. of predators). */
-#define NUM_SPECIES 2*NPREY
+#define NPREY       1 /* No. of prey (= no. of predators). */
+#define NUM_SPECIES 2 * NPREY
 
-#define PI          RCONST(3.1415926535898)
-#define FOURPI      (RCONST(4.0)*PI)
+#define PI     SUN_RCONST(3.1415926535898)
+#define FOURPI (SUN_RCONST(4.0) * PI)
 
-#define MX          20             /* MX = number of x mesh points      */
-#define MY          20             /* MY = number of y mesh points      */
-#define NSMX        (NUM_SPECIES * MX)
-#define NEQ         (NUM_SPECIES*MX*MY)
-#define AA          RCONST(1.0)    /* Coefficient in above eqns. for a  */
-#define EE          RCONST(10000.) /* Coefficient in above eqns. for a  */
-#define GG          RCONST(0.5e-6) /* Coefficient in above eqns. for a  */
-#define BB          RCONST(1.0)    /* Coefficient in above eqns. for b  */
-#define DPREY       RCONST(1.0)    /* Coefficient in above eqns. for d  */
-#define DPRED       RCONST(0.05)   /* Coefficient in above eqns. for d  */
-#define ALPHA       RCONST(50.)    /* Coefficient alpha in above eqns.  */
-#define BETA        RCONST(1000.)  /* Coefficient beta in above eqns.   */
-#define AX          RCONST(1.0)    /* Total range of x variable         */
-#define AY          RCONST(1.0)    /* Total range of y variable         */
-#define RTOL        RCONST(1.e-5)  /* Relative tolerance                */
-#define ATOL        RCONST(1.e-5)  /* Absolute tolerance                */
-#define NOUT        6              /* Number of output times            */
-#define TMULT       RCONST(10.0)   /* Multiplier for tout values        */
-#define TADD        RCONST(0.3)    /* Increment for tout values         */
-#define ZERO        RCONST(0.)     
-#define ONE         RCONST(1.0)    
+#define MX    20 /* MX = number of x mesh points      */
+#define MY    20 /* MY = number of y mesh points      */
+#define NSMX  (NUM_SPECIES * MX)
+#define NEQ   (NUM_SPECIES * MX * MY)
+#define AA    SUN_RCONST(1.0)    /* Coefficient in above eqns. for a  */
+#define EE    SUN_RCONST(10000.) /* Coefficient in above eqns. for a  */
+#define GG    SUN_RCONST(0.5e-6) /* Coefficient in above eqns. for a  */
+#define BB    SUN_RCONST(1.0)    /* Coefficient in above eqns. for b  */
+#define DPREY SUN_RCONST(1.0)    /* Coefficient in above eqns. for d  */
+#define DPRED SUN_RCONST(0.05)   /* Coefficient in above eqns. for d  */
+#define ALPHA SUN_RCONST(50.)    /* Coefficient alpha in above eqns.  */
+#define BETA  SUN_RCONST(1000.)  /* Coefficient beta in above eqns.   */
+#define AX    SUN_RCONST(1.0)    /* Total range of x variable         */
+#define AY    SUN_RCONST(1.0)    /* Total range of y variable         */
+#define RTOL  SUN_RCONST(1.e-5)  /* Relative tolerance                */
+#define ATOL  SUN_RCONST(1.e-5)  /* Absolute tolerance                */
+#define NOUT  6                  /* Number of output times            */
+#define TMULT SUN_RCONST(10.0)   /* Multiplier for tout values        */
+#define TADD  SUN_RCONST(0.3)    /* Increment for tout values         */
+#define ZERO  SUN_RCONST(0.)
+#define ONE   SUN_RCONST(1.0)
 
-/* 
+/*
  * User-defined vector and accessor macro: IJ_Vptr.
- * IJ_Vptr is defined in order to express the underlying 3-D structure of 
+ * IJ_Vptr is defined in order to express the underlying 3-D structure of
  * the dependent variable vector from its underlying 1-D storage (an N_Vector).
- * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to 
- * species index is = 0, x-index ix = i, and y-index jy = j.                
+ * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to
+ * species index is = 0, x-index ix = i, and y-index jy = j.
  */
 
-#define IJ_Vptr(vv,i,j) (&NV_Ith_OMP(vv, (i)*NUM_SPECIES + (j)*NSMX))
+#define IJ_Vptr(vv, i, j) (&NV_Ith_OMP(vv, (i) * NUM_SPECIES + (j) * NSMX))
 
 /* Type: UserData.  Contains problem constants, etc. */
 
-typedef struct {
+typedef struct
+{
   sunindextype Neq, ns, np, mx, my;
-  realtype dx, dy, **acoef;
-  realtype cox[NUM_SPECIES], coy[NUM_SPECIES], bcoef[NUM_SPECIES];
+  sunrealtype dx, dy, **acoef;
+  sunrealtype cox[NUM_SPECIES], coy[NUM_SPECIES], bcoef[NUM_SPECIES];
   N_Vector rates;
   int nthreads;
-} *UserData;
+}* UserData;
 
 /* Prototypes for functions called by the IDA Solver. */
 
-static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval, 
-                  void *user_data);
+static int resweb(sunrealtype time, N_Vector cc, N_Vector cp, N_Vector resval,
+                  void* user_data);
 
 /* Prototypes for private Helper Functions. */
 
 static void InitUserData(UserData webdata);
 static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
                                UserData webdata);
-static void PrintHeader(sunindextype mu, sunindextype ml, realtype rtol, realtype atol);
-static void PrintOutput(void *ida_mem, N_Vector c, realtype t);
-static void PrintFinalStats(void *ida_mem);
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate, UserData webdata);
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy, 
-                     UserData webdata);
-static realtype dotprod(sunindextype size, realtype *x1, realtype *x2);
-static int check_retval(void *returnvalue, char *funcname, int opt);
+static void PrintHeader(sunindextype mu, sunindextype ml, sunrealtype rtol,
+                        sunrealtype atol);
+static void PrintOutput(void* ida_mem, N_Vector c, sunrealtype t);
+static void PrintFinalStats(void* ida_mem);
+static void Fweb(sunrealtype tcalc, N_Vector cc, N_Vector crate,
+                 UserData webdata);
+static void WebRates(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                     sunrealtype* ratesxy, UserData webdata);
+static sunrealtype dotprod(sunindextype size, sunrealtype* x1, sunrealtype* x2);
+static int check_retval(void* returnvalue, const char* funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -199,113 +197,122 @@ static int check_retval(void *returnvalue, char *funcname, int opt);
  *--------------------------------------------------------------------
  */
 
-int main(int argc, char *argv[])
-{ 
-  void *ida_mem;
+int main(int argc, char* argv[])
+{
+  void* ida_mem;
   SUNMatrix A;
   SUNLinearSolver LS;
   UserData webdata;
   N_Vector cc, cp, id;
   int iout, retval;
   sunindextype mu, ml;
-  realtype rtol, atol, t0, tout, tret;
+  sunrealtype rtol, atol, t0, tout, tret;
   int num_threads;
+  SUNContext ctx;
 
   ida_mem = NULL;
-  A = NULL;
-  LS = NULL;
+  A       = NULL;
+  LS      = NULL;
   webdata = NULL;
   cc = cp = id = NULL;
 
   /* Set the number of threads to use */
-  num_threads = 1;       /* default value */
+  num_threads = 1; /* default value */
 #ifdef _OPENMP
-  num_threads = omp_get_max_threads();  /* overwrite with OMP_NUM_THREADS enviroment variable */
+  num_threads =
+    omp_get_max_threads(); /* overwrite with OMP_NUM_THREADS environment variable */
 #endif
-  if (argc > 1)      /* overwrite with command line value, if supplied */
-    num_threads = strtol(argv[1], NULL, 0);
+  if (argc > 1)
+  { /* overwrite with command line value, if supplied */
+    num_threads = (int)strtol(argv[1], NULL, 0);
+  }
+
+  /* Create the SUNDIALS context object for this simulation */
+
+  retval = SUNContext_Create(SUN_COMM_NULL, &ctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) { return 1; }
 
   /* Allocate and initialize user data block webdata. */
 
-  webdata = (UserData) malloc(sizeof *webdata);
-  webdata->rates = N_VNew_OpenMP(NEQ, num_threads);
-  webdata->acoef = newDenseMat(NUM_SPECIES, NUM_SPECIES);
+  webdata           = (UserData)malloc(sizeof *webdata);
+  webdata->rates    = N_VNew_OpenMP(NEQ, num_threads, ctx);
+  webdata->acoef    = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
   webdata->nthreads = num_threads;
 
   InitUserData(webdata);
 
   /* Allocate N-vectors and initialize cc, cp, and id. */
 
-  cc  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_retval((void *)cc, "N_VNew_OpenMP", 0)) return(1);
+  cc = N_VNew_OpenMP(NEQ, num_threads, ctx);
+  if (check_retval((void*)cc, "N_VNew_OpenMP", 0)) { return (1); }
 
-  cp  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_retval((void *)cp, "N_VNew_OpenMP", 0)) return(1);
+  cp = N_VClone(cc);
+  if (check_retval((void*)cp, "N_VNew_OpenMP", 0)) { return (1); }
+
+  id = N_VClone(cc);
+  if (check_retval((void*)id, "N_VNew_OpenMP", 0)) { return (1); }
 
-  id  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_retval((void *)id, "N_VNew_OpenMP", 0)) return(1);
-  
   SetInitialProfiles(cc, cp, id, webdata);
-  
+
   /* Set remaining inputs to IDAMalloc. */
-  
-  t0 = ZERO;
-  rtol = RTOL; 
+
+  t0   = ZERO;
+  rtol = RTOL;
   atol = ATOL;
 
   /* Call IDACreate and IDAMalloc to initialize IDA. */
-  
-  ida_mem = IDACreate();
-  if(check_retval((void *)ida_mem, "IDACreate", 0)) return(1);
+
+  ida_mem = IDACreate(ctx);
+  if (check_retval((void*)ida_mem, "IDACreate", 0)) { return (1); }
 
   retval = IDASetUserData(ida_mem, webdata);
-  if(check_retval(&retval, "IDASetUserData", 1)) return(1);
+  if (check_retval(&retval, "IDASetUserData", 1)) { return (1); }
 
   retval = IDASetId(ida_mem, id);
-  if(check_retval(&retval, "IDASetId", 1)) return(1);
+  if (check_retval(&retval, "IDASetId", 1)) { return (1); }
 
   retval = IDAInit(ida_mem, resweb, t0, cc, cp);
-  if(check_retval(&retval, "IDAInit", 1)) return(1);
+  if (check_retval(&retval, "IDAInit", 1)) { return (1); }
 
   retval = IDASStolerances(ida_mem, rtol, atol);
-  if(check_retval(&retval, "IDASStolerances", 1)) return(1);
+  if (check_retval(&retval, "IDASStolerances", 1)) { return (1); }
 
   /* Setup band matrix and linear solver, and attach to IDA. */
 
   mu = ml = NSMX;
-  A = SUNBandMatrix(NEQ, mu, ml);
-  if(check_retval((void *)A, "SUNBandMatrix", 0)) return(1);
-  LS = SUNLinSol_Band(cc, A);
-  if(check_retval((void *)LS, "SUNLinSol_Band", 0)) return(1);
+  A       = SUNBandMatrix(NEQ, mu, ml, ctx);
+  if (check_retval((void*)A, "SUNBandMatrix", 0)) { return (1); }
+  LS = SUNLinSol_Band(cc, A, ctx);
+  if (check_retval((void*)LS, "SUNLinSol_Band", 0)) { return (1); }
   retval = IDASetLinearSolver(ida_mem, LS, A);
-  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
+  if (check_retval(&retval, "IDASetLinearSolver", 1)) { return (1); }
 
   /* Call IDACalcIC (with default options) to correct the initial values. */
 
-  tout = RCONST(0.001);
+  tout   = SUN_RCONST(0.001);
   retval = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
-  if(check_retval(&retval, "IDACalcIC", 1)) return(1);
-  
+  if (check_retval(&retval, "IDACalcIC", 1)) { return (1); }
+
   /* Print heading, basic parameters, and initial values. */
 
   PrintHeader(mu, ml, rtol, atol);
   PrintOutput(ida_mem, cc, ZERO);
-  
+
   /* Loop over iout, call IDASolve (normal mode), print selected output. */
-  
-  for (iout = 1; iout <= NOUT; iout++) {
-    
+
+  for (iout = 1; iout <= NOUT; iout++)
+  {
     retval = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
-    if(check_retval(&retval, "IDASolve", 1)) return(retval);
-    
+    if (check_retval(&retval, "IDASolve", 1)) { return (retval); }
+
     PrintOutput(ida_mem, cc, tret);
-    
-    if (iout < 3) tout *= TMULT; else tout += TADD;
-    
+
+    if (iout < 3) { tout *= TMULT; }
+    else { tout += TADD; }
   }
-  
-  /* Print final statistics and free memory. */  
-  
+
+  /* Print final statistics and free memory. */
+
   PrintFinalStats(ida_mem);
   printf("num_threads = %i\n\n", num_threads);
 
@@ -319,20 +326,21 @@ int main(int argc, char *argv[])
   N_VDestroy_OpenMP(cp);
   N_VDestroy_OpenMP(id);
 
-
-  destroyMat(webdata->acoef);
+  SUNDlsMat_destroyMat(webdata->acoef);
   N_VDestroy_OpenMP(webdata->rates);
   free(webdata);
 
-  return(0);
+  SUNContext_Free(&ctx);
+
+  return (0);
 }
 
-/* Define lines for readability in later routines */ 
+/* Define lines for readability in later routines */
 
-#define acoef  (webdata->acoef)
-#define bcoef  (webdata->bcoef)
-#define cox    (webdata->cox)
-#define coy    (webdata->coy)
+#define acoef (webdata->acoef)
+#define bcoef (webdata->bcoef)
+#define cox   (webdata->cox)
+#define coy   (webdata->coy)
 
 /*
  *--------------------------------------------------------------------
@@ -340,47 +348,50 @@ int main(int argc, char *argv[])
  *--------------------------------------------------------------------
  */
 
-/* 
+/*
  * resweb: System residual function for predator-prey system.
  * This routine calls Fweb to get all the right-hand sides of the
  * equations, then loads the residual vector accordingly,
- * using cp in the case of prey species.                 
+ * using cp in the case of prey species.
  */
 
-static int resweb(realtype tt, N_Vector cc, N_Vector cp, 
-                  N_Vector res,  void *user_data)
+static int resweb(sunrealtype tt, N_Vector cc, N_Vector cp, N_Vector res,
+                  void* user_data)
 {
   sunindextype jx, jy, is, yloc, loc, np;
-  realtype *resv, *cpv;
+  sunrealtype *resv, *cpv;
   UserData webdata;
-  
+
+  jx = jy = is = 0;
+
   webdata = (UserData)user_data;
-  
-  cpv = NV_DATA_OMP(cp);
+
+  cpv  = NV_DATA_OMP(cp);
   resv = NV_DATA_OMP(res);
-  np = webdata->np;
-  
+  np   = webdata->np;
+
   /* Call Fweb to set res to vector of right-hand sides. */
   Fweb(tt, cc, res, webdata);
-  
+
   /* Loop over all grid points, setting residual values appropriately
      for differential or algebraic components.                        */
-#pragma omp parallel for default(shared) private(jy, yloc, jx, loc, is) schedule(static) num_threads(webdata->nthreads)
-  for (jy = 0; jy < MY; jy++) {
+#pragma omp parallel for default(shared) private(jy, yloc, jx, loc, is) \
+  schedule(static) num_threads(webdata->nthreads)
+  for (jy = 0; jy < MY; jy++)
+  {
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
+    for (jx = 0; jx < MX; jx++)
+    {
       loc = yloc + NUM_SPECIES * jx;
-      for (is = 0; is < NUM_SPECIES; is++) {
-        if (is < np)
-          resv[loc+is] = cpv[loc+is] - resv[loc+is];
-        else
-          resv[loc+is] = -resv[loc+is];
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
+        if (is < np) { resv[loc + is] = cpv[loc + is] - resv[loc + is]; }
+        else { resv[loc + is] = -resv[loc + is]; }
       }
     }
   }
-  
-  return(0);
-  
+
+  return (0);
 }
 
 /*
@@ -390,105 +401,116 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
  */
 
 /*
- * InitUserData: Load problem constants in webdata (of type UserData).   
+ * InitUserData: Load problem constants in webdata (of type UserData).
  */
 
 static void InitUserData(UserData webdata)
 {
-  int i, j, np;
-  realtype *a1,*a2, *a3, *a4, dx2, dy2;
+  sunindextype i, j, np;
+  sunrealtype *a1, *a2, *a3, *a4, dx2, dy2;
+
+  webdata->mx  = MX;
+  webdata->my  = MY;
+  webdata->ns  = NUM_SPECIES;
+  webdata->np  = NPREY;
+  webdata->dx  = AX / (MX - 1);
+  webdata->dy  = AY / (MY - 1);
+  webdata->Neq = NEQ;
 
-  webdata->mx = MX;
-  webdata->my = MY;
-  webdata->ns = NUM_SPECIES;
-  webdata->np = NPREY;
-  webdata->dx = AX/(MX-1);
-  webdata->dy = AY/(MY-1);
-  webdata->Neq= NEQ;
-  
   /* Set up the coefficients a and b, and others found in the equations. */
-  np = webdata->np;
-  dx2 = (webdata->dx)*(webdata->dx); dy2 = (webdata->dy)*(webdata->dy);
-  
-  for (i = 0; i < np; i++) {
+  np  = webdata->np;
+  dx2 = (webdata->dx) * (webdata->dx);
+  dy2 = (webdata->dy) * (webdata->dy);
+
+  for (i = 0; i < np; i++)
+  {
     a1 = &(acoef[i][np]);
-    a2 = &(acoef[i+np][0]);
+    a2 = &(acoef[i + np][0]);
     a3 = &(acoef[i][0]);
-    a4 = &(acoef[i+np][np]);
+    a4 = &(acoef[i + np][np]);
     /*  Fill in the portion of acoef in the four quadrants, row by row. */
-    for (j = 0; j < np; j++) {
-      *a1++ =  -GG;
-      *a2++ =   EE;
+    for (j = 0; j < np; j++)
+    {
+      *a1++ = -GG;
+      *a2++ = EE;
       *a3++ = ZERO;
       *a4++ = ZERO;
     }
-    
+
     /* Reset the diagonal elements of acoef to -AA. */
-    acoef[i][i] = -AA; acoef[i+np][i+np] = -AA;
-    
+    acoef[i][i]           = -AA;
+    acoef[i + np][i + np] = -AA;
+
     /* Set coefficients for b and diffusion terms. */
-    bcoef[i] = BB; bcoef[i+np] = -BB;
-    cox[i] = DPREY/dx2; cox[i+np] = DPRED/dx2;
-    coy[i] = DPREY/dy2; coy[i+np] = DPRED/dy2;
+    bcoef[i]      = BB;
+    bcoef[i + np] = -BB;
+    cox[i]        = DPREY / dx2;
+    cox[i + np]   = DPRED / dx2;
+    coy[i]        = DPREY / dy2;
+    coy[i + np]   = DPRED / dy2;
   }
-  
 }
 
-/* 
+/*
  * SetInitialProfiles: Set initial conditions in cc, cp, and id.
  * A polynomial profile is used for the prey cc values, and a constant
  * (1.0e5) is loaded as the initial guess for the predator cc values.
  * The id values are set to 1 for the prey and 0 for the predators.
  * The prey cp values are set according to the given system, and
- * the predator cp values are set to zero.                               
+ * the predator cp values are set to zero.
  */
 
 static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
                                UserData webdata)
 {
   sunindextype loc, yloc, is, jx, jy, np;
-  realtype xx, yy, xyfactor;
-  realtype *ccv, *cpv, *idv;
-  
+  sunrealtype xx, yy, xyfactor;
+  sunrealtype *ccv, *cpv, *idv;
+
   ccv = NV_DATA_OMP(cc);
   cpv = NV_DATA_OMP(cp);
   idv = NV_DATA_OMP(id);
-  np = webdata->np;
-  
+  np  = webdata->np;
+
   /* Loop over grid, load cc values and id values. */
-  for (jy = 0; jy < MY; jy++) {
-    yy = jy * webdata->dy;
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy   = jy * webdata->dy;
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
-      xx = jx * webdata->dx;
-      xyfactor = RCONST(16.0)*xx*(ONE-xx)*yy*(ONE-yy);
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx       = jx * webdata->dx;
+      xyfactor = SUN_RCONST(16.0) * xx * (ONE - xx) * yy * (ONE - yy);
       xyfactor *= xyfactor;
-      loc = yloc + NUM_SPECIES*jx;
-       
-      for (is = 0; is < NUM_SPECIES; is++) {
-        if (is < np) {
-          ccv[loc+is] = RCONST(10.0) + (realtype)(is+1) * xyfactor;
-          idv[loc+is] = ONE;
+      loc = yloc + NUM_SPECIES * jx;
+
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
+        if (is < np)
+        {
+          ccv[loc + is] = SUN_RCONST(10.0) + (sunrealtype)(is + 1) * xyfactor;
+          idv[loc + is] = ONE;
         }
-        else {
-	  ccv[loc+is] = RCONST(1.0e5);
-          idv[loc+is] = ZERO;
+        else
+        {
+          ccv[loc + is] = SUN_RCONST(1.0e5);
+          idv[loc + is] = ZERO;
         }
       }
     }
   }
-  
+
   /* Set c' for the prey by calling the function Fweb. */
   Fweb(ZERO, cc, cp, webdata);
-  
+
   /* Set c' for predators to 0. */
-  for (jy = 0; jy < MY; jy++) {
+  for (jy = 0; jy < MY; jy++)
+  {
     yloc = NSMX * jy;
-    for (jx = 0; jx < MX; jx++) {
+    for (jx = 0; jx < MX; jx++)
+    {
       loc = yloc + NUM_SPECIES * jx;
-      for (is = np; is < NUM_SPECIES; is++) {
-        cpv[loc+is] = ZERO;
-      }
+      for (is = np; is < NUM_SPECIES; is++) { cpv[loc + is] = ZERO; }
     }
   }
 }
@@ -497,40 +519,41 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
  * Print first lines of output (problem description)
  */
 
-static void PrintHeader(sunindextype mu, sunindextype ml, realtype rtol, realtype atol)
+static void PrintHeader(sunindextype mu, sunindextype ml, sunrealtype rtol,
+                        sunrealtype atol)
 {
-  printf("\nidasFoodWeb_bnd_omp: Predator-prey DAE OpenMP example problem for IDAS \n\n");
+  printf("\nidasFoodWeb_bnd_omp: Predator-prey DAE OpenMP example problem for "
+         "IDAS \n\n");
   printf("Number of species ns: %d", NUM_SPECIES);
   printf("     Mesh dimensions: %d x %d", MX, MY);
   printf("     System size: %d\n", NEQ);
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
   printf("Linear solver: SUNBAND,  Band parameters mu = %ld, ml = %ld\n",
-         (long int) mu, (long int) ml);
+         (long int)mu, (long int)ml);
   printf("CalcIC called to correct initial predator concentrations.\n\n");
   printf("-----------------------------------------------------------\n");
   printf("  t        bottom-left  top-right");
   printf("    | nst  k      h\n");
   printf("-----------------------------------------------------------\n\n");
-  
 }
 
-/* 
+/*
  * PrintOutput: Print output values at output time t = tt.
  * Selected run statistics are printed.  Then values of the concentrations
- * are printed for the bottom left and top right grid points only.  
+ * are printed for the bottom left and top right grid points only.
  */
 
-static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
+static void PrintOutput(void* ida_mem, N_Vector c, sunrealtype t)
 {
   int i, kused, retval;
   long int nst;
-  realtype *c_bl, *c_tr, hused;
+  sunrealtype *c_bl, *c_tr, hused;
 
   retval = IDAGetLastOrder(ida_mem, &kused);
   check_retval(&retval, "IDAGetLastOrder", 1);
@@ -538,36 +561,38 @@ static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
   check_retval(&retval, "IDAGetNumSteps", 1);
   retval = IDAGetLastStep(ida_mem, &hused);
   check_retval(&retval, "IDAGetLastStep", 1);
-  
-  c_bl = IJ_Vptr(c,0,0);
-  c_tr = IJ_Vptr(c,MX-1,MY-1);
 
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
-  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", 
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4Le %12.4Le   |\n",c_bl[i],c_tr[i]);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
+  c_bl = IJ_Vptr(c, 0, 0);
+  c_tr = IJ_Vptr(c, MX - 1, MY - 1);
+
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", t, c_bl[0], c_tr[0],
+         nst, kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+    printf("         %12.4Le %12.4Le   |\n", c_bl[i], c_tr[i]);
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", t, c_bl[0], c_tr[0], nst,
+         kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+  {
+    printf("         %12.4e %12.4e   |\n", c_bl[i], c_tr[i]);
+  }
 #else
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
-         t, c_bl[0], c_tr[0], nst, kused, hused);
-  for (i=1;i<NUM_SPECIES;i++)
-    printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", t, c_bl[0], c_tr[0], nst,
+         kused, hused);
+  for (i = 1; i < NUM_SPECIES; i++)
+    printf("         %12.4e %12.4e   |\n", c_bl[i], c_tr[i]);
 #endif
 
   printf("\n");
 }
 
-/* 
- * PrintFinalStats: Print final run data contained in iopt.              
+/*
+ * PrintFinalStats: Print final run data contained in iopt.
  */
 
-static void PrintFinalStats(void *ida_mem)
-{ 
+static void PrintFinalStats(void* ida_mem)
+{
   long int nst, nre, nreLS, nni, nje, netf, ncfn;
   int retval;
 
@@ -589,102 +614,107 @@ static void PrintFinalStats(void *ida_mem)
   printf("-----------------------------------------------------------\n");
   printf("Final run statistics: \n\n");
   printf("Number of steps                    = %ld\n", nst);
-  printf("Number of residual evaluations     = %ld\n", nre+nreLS);
+  printf("Number of residual evaluations     = %ld\n", nre + nreLS);
   printf("Number of Jacobian evaluations     = %ld\n", nje);
   printf("Number of nonlinear iterations     = %ld\n", nni);
   printf("Number of error test failures      = %ld\n", netf);
   printf("Number of nonlinear conv. failures = %ld\n", ncfn);
-
 }
 
-/* 
- * Fweb: Rate function for the food-web problem.                        
- * This routine computes the right-hand sides of the system equations,   
- * consisting of the diffusion term and interaction term.                
- * The interaction term is computed by the function WebRates.            
+/*
+ * Fweb: Rate function for the food-web problem.
+ * This routine computes the right-hand sides of the system equations,
+ * consisting of the diffusion term and interaction term.
+ * The interaction term is computed by the function WebRates.
  */
 
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,  
-                 UserData webdata)
-{ 
+static void Fweb(sunrealtype tcalc, N_Vector cc, N_Vector crate, UserData webdata)
+{
   sunindextype jx, jy, is, idyu, idyl, idxu, idxl;
-  realtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
-  
+  sunrealtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
+
   /* Loop over grid points, evaluate interaction vector (length ns),
      form diffusion difference terms, and load crate.                    */
-  
-  for (jy = 0; jy < MY; jy++) {
-    yy = (webdata->dy) * jy ;
-    idyu = (jy!=MY-1) ? NSMX : -NSMX;
-    idyl = (jy!= 0  ) ? NSMX : -NSMX;
-    
-    for (jx = 0; jx < MX; jx++) {
-      xx = (webdata->dx) * jx;
-      idxu = (jx!= MX-1) ?  NUM_SPECIES : -NUM_SPECIES;
-      idxl = (jx!=  0  ) ?  NUM_SPECIES : -NUM_SPECIES;
-      cxy = IJ_Vptr(cc,jx,jy);
-      ratesxy = IJ_Vptr(webdata->rates,jx,jy);
-      cratexy = IJ_Vptr(crate,jx,jy);
-      
+
+  jx = jy = is = 0;
+
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy   = (webdata->dy) * jy;
+    idyu = (jy != MY - 1) ? NSMX : -NSMX;
+    idyl = (jy != 0) ? NSMX : -NSMX;
+
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx      = (webdata->dx) * jx;
+      idxu    = (jx != MX - 1) ? NUM_SPECIES : -NUM_SPECIES;
+      idxl    = (jx != 0) ? NUM_SPECIES : -NUM_SPECIES;
+      cxy     = IJ_Vptr(cc, jx, jy);
+      ratesxy = IJ_Vptr(webdata->rates, jx, jy);
+      cratexy = IJ_Vptr(crate, jx, jy);
+
       /* Get interaction vector at this grid point. */
       WebRates(xx, yy, cxy, ratesxy, webdata);
-      
+
       /* Loop over species, do differencing, load crate segment. */
-#pragma omp parallel for default(shared) private(is, dcyli, dcyui, dcxli, dcxui) schedule(static) num_threads(webdata->nthreads)
-      for (is = 0; is < NUM_SPECIES; is++) {
-        
+#pragma omp parallel for default(shared) private(is, dcyli, dcyui, dcxli, dcxui) \
+  schedule(static) num_threads(webdata->nthreads)
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
         /* Differencing in y. */
-        dcyli = *(cxy+is) - *(cxy - idyl + is) ;
-        dcyui = *(cxy + idyu + is) - *(cxy+is);
-        
+        dcyli = *(cxy + is) - *(cxy - idyl + is);
+        dcyui = *(cxy + idyu + is) - *(cxy + is);
+
         /* Differencing in x. */
-        dcxli = *(cxy+is) - *(cxy - idxl + is);
-        dcxui = *(cxy + idxu +is) - *(cxy+is);
-        
+        dcxli = *(cxy + is) - *(cxy - idxl + is);
+        dcxui = *(cxy + idxu + is) - *(cxy + is);
+
         /* Compute the crate values at (xx,yy). */
-        cratexy[is] = coy[is] * (dcyui - dcyli) +
-          cox[is] * (dcxui - dcxli) + ratesxy[is];
-        
+        cratexy[is] = coy[is] * (dcyui - dcyli) + cox[is] * (dcxui - dcxli) +
+                      ratesxy[is];
+
       } /* End is loop */
-    } /* End of jx loop */
-  } /* End of jy loop */
-  
+    }   /* End of jx loop */
+  }     /* End of jy loop */
 }
 
-/* 
+/*
  * WebRates: Evaluate reaction rates at a given spatial point.
  * At a given (x,y), evaluate the array of ns reaction terms R.
  */
 
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
-                     UserData webdata)
+static void WebRates(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                     sunrealtype* ratesxy, UserData webdata)
 {
   int is;
-  realtype fac;
-  
+  sunrealtype fac;
+
   for (is = 0; is < NUM_SPECIES; is++)
+  {
     ratesxy[is] = dotprod(NUM_SPECIES, cxy, acoef[is]);
-  
-  fac = ONE + ALPHA*xx*yy + BETA*sin(FOURPI*xx)*sin(FOURPI*yy);
-   
-  for (is = 0; is < NUM_SPECIES; is++)  
-    ratesxy[is] = cxy[is]*( bcoef[is]*fac + ratesxy[is] );
-  
+  }
+
+  fac = ONE + ALPHA * xx * yy + BETA * sin(FOURPI * xx) * sin(FOURPI * yy);
+
+  for (is = 0; is < NUM_SPECIES; is++)
+  {
+    ratesxy[is] = cxy[is] * (bcoef[is] * fac + ratesxy[is]);
+  }
 }
 
 /*
- * dotprod: dot product routine for realtype arrays, for use by WebRates.    
+ * dotprod: dot product routine for sunrealtype arrays, for use by WebRates.
  */
 
-static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
+static sunrealtype dotprod(sunindextype size, sunrealtype* x1, sunrealtype* x2)
 {
   sunindextype i;
-  realtype *xx1, *xx2, temp = ZERO;
-  
-  xx1 = x1; xx2 = x2;
-  for (i = 0; i < size; i++) temp += (*xx1++) * (*xx2++);
-  return(temp);
-  
+  sunrealtype *xx1, *xx2, temp = ZERO;
+
+  xx1 = x1;
+  xx2 = x2;
+  for (i = 0; i < size; i++) { temp += (*xx1++) * (*xx2++); }
+  return (temp);
 }
 
 /*
@@ -694,35 +724,38 @@ static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
  *   opt == 1 means SUNDIALS function returns an integer value so check if
  *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
- *            NULL pointer 
+ *            NULL pointer
  */
 
-static int check_retval(void *returnvalue, char *funcname, int opt)
+static int check_retval(void* returnvalue, const char* funcname, int opt)
 {
-  int *retval;
+  int* retval;
 
-  if (opt == 0 && returnvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL)
+  {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1);
-  } else if (opt == 1) {
+    return (1);
+  }
+  else if (opt == 1)
+  {
     /* Check if retval < 0 */
-    retval = (int *) returnvalue;
-    if (*retval < 0) {
-      fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n", 
+    retval = (int*)returnvalue;
+    if (*retval < 0)
+    {
+      fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
               funcname, *retval);
-      return(1); 
+      return (1);
     }
-  } else if (opt == 2 && returnvalue == NULL) {
+  }
+  else if (opt == 2 && returnvalue == NULL)
+  {
     /* Check if function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1); 
+    return (1);
   }
 
-  return(0);
+  return (0);
 }
