@@ -3,7 +3,7 @@
  *                Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2023, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -83,45 +83,43 @@
  * -----------------------------------------------------------------
  */
 
+#include <kinsol/kinsol.h> /* access to KINSOL func., consts.      */
+#include <math.h>
+#include <nvector/nvector_serial.h> /* access to serial N_Vector            */
 #include <stdio.h>
 #include <stdlib.h>
-#include <math.h>
-
-#include <kinsol/kinsol.h>             /* access to KINSOL func., consts.      */
-#include <nvector/nvector_serial.h>    /* access to serial N_Vector            */
+#include <sundials/sundials_dense.h> /* use generic dense solver in precond. */
+#include <sundials/sundials_math.h>  /* access to SUNMAX, SUNRabs, SUNRsqrt  */
+#include <sundials/sundials_types.h> /* defs. of sunrealtype, sunindextype      */
 #include <sunlinsol/sunlinsol_spgmr.h> /* access to SPGMR SUNLinearSolver      */
-#include <sundials/sundials_dense.h>   /* use generic dense solver in precond. */
-#include <sundials/sundials_types.h>   /* defs. of realtype, sunindextype      */
-#include <sundials/sundials_math.h>    /* access to SUNMAX, SUNRabs, SUNRsqrt  */
 
 /* Problem Constants */
 
-#define NUM_SPECIES     6  /* must equal 2*(number of prey or predators)
+#define NUM_SPECIES \
+  6 /* must equal 2*(number of prey or predators)
                               number of prey = number of predators       */
 
-#define PI       RCONST(3.1415926535898)   /* pi */
-
-#define MX          8              /* MX = number of x mesh points */
-#define MY          8              /* MY = number of y mesh points */
-#define NSMX        (NUM_SPECIES * MX)
-#define NEQ         (NSMX * MY)    /* number of equations in the system */
-#define AA          RCONST(1.0)    /* value of coefficient AA in above eqns */
-#define EE          RCONST(10000.) /* value of coefficient EE in above eqns */
-#define GG          RCONST(0.5e-6) /* value of coefficient GG in above eqns */
-#define BB          RCONST(1.0)    /* value of coefficient BB in above eqns */
-#define DPREY       RCONST(1.0)    /* value of coefficient dprey above */
-#define DPRED       RCONST(0.5)    /* value of coefficient dpred above */
-#define ALPHA       RCONST(1.0)    /* value of coefficient alpha above */
-#define AX          RCONST(1.0)    /* total range of x variable */
-#define AY          RCONST(1.0)    /* total range of y variable */
-#define FTOL        RCONST(1.e-7)  /* ftol tolerance */
-#define STOL        RCONST(1.e-13) /* stol tolerance */
-#define THOUSAND    RCONST(1000.0) /* one thousand */
-#define ZERO        RCONST(0.0)    /* 0. */
-#define ONE         RCONST(1.0)    /* 1. */
-#define TWO         RCONST(2.0)    /* 2. */
-#define PREYIN      RCONST(1.0)    /* initial guess for prey concentrations. */
-#define PREDIN      RCONST(30000.0)/* initial guess for predator concs.      */
+#define MX       8 /* MX = number of x mesh points */
+#define MY       8 /* MY = number of y mesh points */
+#define NSMX     (NUM_SPECIES * MX)
+#define NEQ      (NSMX * MY)        /* number of equations in the system */
+#define AA       SUN_RCONST(1.0)    /* value of coefficient AA in above eqns */
+#define EE       SUN_RCONST(10000.) /* value of coefficient EE in above eqns */
+#define GG       SUN_RCONST(0.5e-6) /* value of coefficient GG in above eqns */
+#define BB       SUN_RCONST(1.0)    /* value of coefficient BB in above eqns */
+#define DPREY    SUN_RCONST(1.0)    /* value of coefficient dprey above */
+#define DPRED    SUN_RCONST(0.5)    /* value of coefficient dpred above */
+#define ALPHA    SUN_RCONST(1.0)    /* value of coefficient alpha above */
+#define AX       SUN_RCONST(1.0)    /* total range of x variable */
+#define AY       SUN_RCONST(1.0)    /* total range of y variable */
+#define FTOL     SUN_RCONST(1.e-7)  /* ftol tolerance */
+#define STOL     SUN_RCONST(1.e-13) /* stol tolerance */
+#define THOUSAND SUN_RCONST(1000.0) /* one thousand */
+#define ZERO     SUN_RCONST(0.0)    /* 0. */
+#define ONE      SUN_RCONST(1.0)    /* 1. */
+#define TWO      SUN_RCONST(2.0)    /* 2. */
+#define PREYIN   SUN_RCONST(1.0)    /* initial guess for prey concentrations. */
+#define PREDIN   SUN_RCONST(30000.0) /* initial guess for predator concs.      */
 
 /* User-defined vector access macro: IJ_Vptr */
 
@@ -130,33 +128,32 @@
    IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to
    indices is = 0, jx = i, jy = j.    */
 
-#define IJ_Vptr(vv,i,j)   (&NV_Ith_S(vv, i*NUM_SPECIES + j*NSMX))
+#define IJ_Vptr(vv, i, j) (&NV_Ith_S(vv, i * NUM_SPECIES + j * NSMX))
 
 /* Type : UserData
    contains preconditioner blocks, pivot arrays, and problem constants */
 
-typedef struct {
-  realtype **P[MX][MY];
-  sunindextype *pivot[MX][MY];
-  realtype **acoef, *bcoef;
+typedef struct
+{
+  sunrealtype** P[MX][MY];
+  sunindextype* pivot[MX][MY];
+  sunrealtype **acoef, *bcoef;
   N_Vector rates;
-  realtype *cox, *coy;
-  realtype ax, ay, dx, dy;
-  realtype uround, sqruround;
+  sunrealtype *cox, *coy;
+  sunrealtype ax, ay, dx, dy;
+  sunrealtype uround, sqruround;
   sunindextype mx, my, ns, np;
-} *UserData;
+}* UserData;
 
 /* Functions Called by the KINSOL Solver */
 
-static int func(N_Vector cc, N_Vector fval, void *user_data);
+static int func(N_Vector cc, N_Vector fval, void* user_data);
 
-static int PrecSetupBD(N_Vector cc, N_Vector cscale,
-                       N_Vector fval, N_Vector fscale,
-                       void *user_data);
+static int PrecSetupBD(N_Vector cc, N_Vector cscale, N_Vector fval,
+                       N_Vector fscale, void* user_data);
 
-static int PrecSolveBD(N_Vector cc, N_Vector cscale,
-                       N_Vector fval, N_Vector fscale,
-                       N_Vector vv, void *user_data);
+static int PrecSolveBD(N_Vector cc, N_Vector cscale, N_Vector fval,
+                       N_Vector fscale, N_Vector vv, void* user_data);
 
 /* Private Helper Functions */
 
@@ -165,13 +162,13 @@ static void InitUserData(UserData data);
 static void FreeUserData(UserData data);
 static void SetInitialProfiles(N_Vector cc, N_Vector sc);
 static void PrintHeader(int globalstrategy, int maxl, int maxlrst,
-                        realtype fnormtol, realtype scsteptol);
+                        sunrealtype fnormtol, sunrealtype scsteptol);
 static void PrintOutput(N_Vector cc);
-static void PrintFinalStats(void *kmem);
-static void WebRate(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
-                    void *user_data);
-static realtype DotProd(sunindextype size, realtype *x1, realtype *x2);
-static int check_retval(void *retvalvalue, const char *funcname, int opt);
+static void PrintFinalStats(void* kmem);
+static void WebRate(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                    sunrealtype* ratesxy, void* user_data);
+static sunrealtype DotProd(sunindextype size, sunrealtype* x1, sunrealtype* x2);
+static int check_retval(void* retvalvalue, const char* funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -183,97 +180,97 @@ int main(void)
 {
   SUNContext sunctx;
   int globalstrategy;
-  realtype fnormtol, scsteptol;
+  sunrealtype fnormtol, scsteptol;
   N_Vector cc, sc, constraints;
   UserData data;
   int retval, maxl, maxlrst;
-  void *kmem;
+  void* kmem;
   SUNLinearSolver LS;
 
   cc = sc = constraints = NULL;
-  kmem = NULL;
-  LS = NULL;
-  data = NULL;
+  kmem                  = NULL;
+  LS                    = NULL;
+  data                  = NULL;
 
   /* Create the SUNDIALS context that all SUNDIALS objects require */
-  retval = SUNContext_Create(NULL, &sunctx);
-  if (check_retval(&retval, "SUNContext_Create", 1)) return(1);
+  retval = SUNContext_Create(SUN_COMM_NULL, &sunctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) { return (1); }
 
   /* Allocate memory, and set problem data, initial values, tolerances */
   globalstrategy = KIN_NONE;
 
   data = AllocUserData();
-  if (check_retval((void *)data, "AllocUserData", 2)) return(1);
+  if (check_retval((void*)data, "AllocUserData", 2)) { return (1); }
   InitUserData(data);
 
   /* Create serial vectors of length NEQ */
   cc = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)cc, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)cc, "N_VNew_Serial", 0)) { return (1); }
   sc = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)sc, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)sc, "N_VNew_Serial", 0)) { return (1); }
   data->rates = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)data->rates, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)data->rates, "N_VNew_Serial", 0)) { return (1); }
 
   constraints = N_VNew_Serial(NEQ, sunctx);
-  if (check_retval((void *)constraints, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void*)constraints, "N_VNew_Serial", 0)) { return (1); }
   N_VConst(TWO, constraints);
 
   SetInitialProfiles(cc, sc);
 
-  fnormtol=FTOL; scsteptol=STOL;
+  fnormtol  = FTOL;
+  scsteptol = STOL;
 
   /* Call KINCreate/KINInit to initialize KINSOL.
      A pointer to KINSOL problem memory is returned and stored in kmem. */
   kmem = KINCreate(sunctx);
-  if (check_retval((void *)kmem, "KINCreate", 0)) return(1);
+  if (check_retval((void*)kmem, "KINCreate", 0)) { return (1); }
 
   /* Vector cc passed as template vector. */
   retval = KINInit(kmem, func, cc);
-  if (check_retval(&retval, "KINInit", 1)) return(1);
+  if (check_retval(&retval, "KINInit", 1)) { return (1); }
 
   retval = KINSetUserData(kmem, data);
-  if (check_retval(&retval, "KINSetUserData", 1)) return(1);
+  if (check_retval(&retval, "KINSetUserData", 1)) { return (1); }
   retval = KINSetConstraints(kmem, constraints);
-  if (check_retval(&retval, "KINSetConstraints", 1)) return(1);
+  if (check_retval(&retval, "KINSetConstraints", 1)) { return (1); }
   retval = KINSetFuncNormTol(kmem, fnormtol);
-  if (check_retval(&retval, "KINSetFuncNormTol", 1)) return(1);
+  if (check_retval(&retval, "KINSetFuncNormTol", 1)) { return (1); }
   retval = KINSetScaledStepTol(kmem, scsteptol);
-  if (check_retval(&retval, "KINSetScaledStepTol", 1)) return(1);
+  if (check_retval(&retval, "KINSetScaledStepTol", 1)) { return (1); }
 
   /* We no longer need the constraints vector since KINSetConstraints
      creates a private copy for KINSOL to use. */
   N_VDestroy(constraints);
 
-
   /* Create SUNLinSol_SPGMR object with right preconditioning and the
      maximum Krylov dimension maxl */
   maxl = 15;
-  LS = SUNLinSol_SPGMR(cc, SUN_PREC_RIGHT, maxl, sunctx);
-  if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0)) return(1);
+  LS   = SUNLinSol_SPGMR(cc, SUN_PREC_RIGHT, maxl, sunctx);
+  if (check_retval((void*)LS, "SUNLinSol_SPGMR", 0)) { return (1); }
 
   /* Attach the linear solver to KINSOL */
   retval = KINSetLinearSolver(kmem, LS, NULL);
-  if (check_retval(&retval, "KINSetLinearSolver", 1)) return 1;
+  if (check_retval(&retval, "KINSetLinearSolver", 1)) { return 1; }
 
   /* Set the maximum number of restarts */
   maxlrst = 2;
-  retval = SUNLinSol_SPGMRSetMaxRestarts(LS, maxlrst);
-  if (check_retval(&retval, "SUNLinSol_SPGMRSetMaxRestarts", 1)) return(1);
+  retval  = SUNLinSol_SPGMRSetMaxRestarts(LS, maxlrst);
+  if (check_retval(&retval, "SUNLinSol_SPGMRSetMaxRestarts", 1)) { return (1); }
 
   /* Specify the preconditioner setup and solve routines */
   retval = KINSetPreconditioner(kmem, PrecSetupBD, PrecSolveBD);
-  if (check_retval(&retval, "KINSetPreconditioner", 1)) return(1);
+  if (check_retval(&retval, "KINSetPreconditioner", 1)) { return (1); }
 
   /* Print out the problem size, solution parameters, initial guess. */
   PrintHeader(globalstrategy, maxl, maxlrst, fnormtol, scsteptol);
 
   /* Call KINSol and print output concentration profile */
   retval = KINSol(kmem,           /* KINSol memory block */
-                cc,             /* initial guess on input; solution vector */
-                globalstrategy, /* global strategy choice */
-                sc,             /* scaling vector for the variable cc */
-                sc);            /* scaling vector for function values fval */
-  if (check_retval(&retval, "KINSol", 1)) return(1);
+                  cc,             /* initial guess on input; solution vector */
+                  globalstrategy, /* global strategy choice */
+                  sc,             /* scaling vector for the variable cc */
+                  sc);            /* scaling vector for function values fval */
+  if (check_retval(&retval, "KINSol", 1)) { return (1); }
 
   printf("\n\nComputed equilibrium species concentrations:\n");
   PrintOutput(cc);
@@ -288,15 +285,15 @@ int main(void)
   FreeUserData(data);
   SUNContext_Free(&sunctx);
 
-  return(0);
+  return (0);
 }
 
 /* Readability definitions used in other routines below */
 
-#define acoef  (data->acoef)
-#define bcoef  (data->bcoef)
-#define cox    (data->cox)
-#define coy    (data->coy)
+#define acoef (data->acoef)
+#define bcoef (data->bcoef)
+#define cox   (data->cox)
+#define coy   (data->coy)
 
 /*
  *--------------------------------------------------------------------
@@ -308,9 +305,9 @@ int main(void)
  * System function for predator-prey system
  */
 
-static int func(N_Vector cc, N_Vector fval, void *user_data)
+static int func(N_Vector cc, N_Vector fval, void* user_data)
 {
-  realtype xx, yy, delx, dely, *cxy, *rxy, *fxy, dcyli, dcyui, dcxli, dcxri;
+  sunrealtype xx, yy, delx, dely, *cxy, *rxy, *fxy, dcyli, dcyui, dcxli, dcxri;
   sunindextype jx, jy, is, idyu, idyl, idxr, idxl;
   UserData data;
 
@@ -319,42 +316,42 @@ static int func(N_Vector cc, N_Vector fval, void *user_data)
   dely = data->dy;
 
   /* Loop over all mesh points, evaluating rate array at each point*/
-  for (jy = 0; jy < MY; jy++) {
-
-    yy = dely*jy;
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy = dely * jy;
 
     /* Set lower/upper index shifts, special at boundaries. */
-    idyl = (jy != 0   ) ? NSMX : -NSMX;
-    idyu = (jy != MY-1) ? NSMX : -NSMX;
+    idyl = (jy != 0) ? NSMX : -NSMX;
+    idyu = (jy != MY - 1) ? NSMX : -NSMX;
 
-    for (jx = 0; jx < MX; jx++) {
-
-      xx = delx*jx;
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx = delx * jx;
 
       /* Set left/right index shifts, special at boundaries. */
-      idxl = (jx !=  0  ) ?  NUM_SPECIES : -NUM_SPECIES;
-      idxr = (jx != MX-1) ?  NUM_SPECIES : -NUM_SPECIES;
+      idxl = (jx != 0) ? NUM_SPECIES : -NUM_SPECIES;
+      idxr = (jx != MX - 1) ? NUM_SPECIES : -NUM_SPECIES;
 
-      cxy = IJ_Vptr(cc,jx,jy);
-      rxy = IJ_Vptr(data->rates,jx,jy);
-      fxy = IJ_Vptr(fval,jx,jy);
+      cxy = IJ_Vptr(cc, jx, jy);
+      rxy = IJ_Vptr(data->rates, jx, jy);
+      fxy = IJ_Vptr(fval, jx, jy);
 
       /* Get species interaction rate array at (xx,yy) */
       WebRate(xx, yy, cxy, rxy, user_data);
 
-      for(is = 0; is < NUM_SPECIES; is++) {
-
+      for (is = 0; is < NUM_SPECIES; is++)
+      {
         /* Differencing in x direction */
-        dcyli = *(cxy+is) - *(cxy - idyl + is) ;
-        dcyui = *(cxy + idyu + is) - *(cxy+is);
+        dcyli = *(cxy + is) - *(cxy - idyl + is);
+        dcyui = *(cxy + idyu + is) - *(cxy + is);
 
         /* Differencing in y direction */
-        dcxli = *(cxy+is) - *(cxy - idxl + is);
-        dcxri = *(cxy + idxr +is) - *(cxy+is);
+        dcxli = *(cxy + is) - *(cxy - idxl + is);
+        dcxri = *(cxy + idxr + is) - *(cxy + is);
 
         /* Compute the total rate value at (xx,yy) */
-        fxy[is] = (coy)[is] * (dcyui - dcyli) +
-          (cox)[is] * (dcxri - dcxli) + rxy[is];
+        fxy[is] = (coy)[is] * (dcyui - dcyli) + (cox)[is] * (dcxri - dcxli) +
+                  rxy[is];
 
       } /* end of is loop */
 
@@ -362,50 +359,51 @@ static int func(N_Vector cc, N_Vector fval, void *user_data)
 
   } /* end of jy loop */
 
-  return(0);
+  return (0);
 }
 
 /*
  * Preconditioner setup routine. Generate and preprocess P.
  */
 
-static int PrecSetupBD(N_Vector cc, N_Vector cscale,
-                       N_Vector fval, N_Vector fscale,
-                       void *user_data)
+static int PrecSetupBD(N_Vector cc, N_Vector cscale, N_Vector fval,
+                       N_Vector fscale, void* user_data)
 {
-  realtype r, r0, uround, sqruround, xx, yy, delx, dely, csave, fac;
-  realtype *cxy, *scxy, **Pxy, *ratesxy, *Pxycol, perturb_rates[NUM_SPECIES];
+  sunrealtype r, r0, uround, sqruround, xx, yy, delx, dely, csave, fac;
+  sunrealtype *cxy, *scxy, **Pxy, *ratesxy, *Pxycol, perturb_rates[NUM_SPECIES];
   sunindextype i, j, jx, jy, ret;
   UserData data;
 
-  data = (UserData) user_data;
+  data = (UserData)user_data;
   delx = data->dx;
   dely = data->dy;
 
-  uround = data->uround;
+  uround    = data->uround;
   sqruround = data->sqruround;
-  fac = N_VWL2Norm(fval, fscale);
-  r0 = THOUSAND * uround * fac * NEQ;
-  if(r0 == ZERO) r0 = ONE;
+  fac       = N_VWL2Norm(fval, fscale);
+  r0        = THOUSAND * uround * fac * NEQ;
+  if (r0 == ZERO) { r0 = ONE; }
 
   /* Loop over spatial points; get size NUM_SPECIES Jacobian block at each */
-  for (jy = 0; jy < MY; jy++) {
-    yy = jy*dely;
+  for (jy = 0; jy < MY; jy++)
+  {
+    yy = jy * dely;
 
-    for (jx = 0; jx < MX; jx++) {
-      xx = jx*delx;
-      Pxy = (data->P)[jx][jy];
-      cxy = IJ_Vptr(cc,jx,jy);
-      scxy= IJ_Vptr(cscale,jx,jy);
-      ratesxy = IJ_Vptr((data->rates),jx,jy);
+    for (jx = 0; jx < MX; jx++)
+    {
+      xx      = jx * delx;
+      Pxy     = (data->P)[jx][jy];
+      cxy     = IJ_Vptr(cc, jx, jy);
+      scxy    = IJ_Vptr(cscale, jx, jy);
+      ratesxy = IJ_Vptr((data->rates), jx, jy);
 
       /* Compute difference quotients of interaction rate fn. */
-      for (j = 0; j < NUM_SPECIES; j++) {
-
-        csave = cxy[j];  /* Save the j,jx,jy element of cc */
-        r = SUNMAX(sqruround*SUNRabs(csave), r0/scxy[j]);
+      for (j = 0; j < NUM_SPECIES; j++)
+      {
+        csave = cxy[j]; /* Save the j,jx,jy element of cc */
+        r     = SUNMAX(sqruround * SUNRabs(csave), r0 / scxy[j]);
         cxy[j] += r; /* Perturb the j,jx,jy element of cc */
-        fac = ONE/r;
+        fac = ONE / r;
 
         WebRate(xx, yy, cxy, perturb_rates, data);
 
@@ -415,44 +413,46 @@ static int PrecSetupBD(N_Vector cc, N_Vector cscale,
         /* Load the j-th column of difference quotients */
         Pxycol = Pxy[j];
         for (i = 0; i < NUM_SPECIES; i++)
+        {
           Pxycol[i] = (perturb_rates[i] - ratesxy[i]) * fac;
+        }
 
       } /* end of j loop */
 
       /* Do LU decomposition of size NUM_SPECIES preconditioner block */
-      ret = SUNDlsMat_denseGETRF(Pxy, NUM_SPECIES, NUM_SPECIES, (data->pivot)[jx][jy]);
-      if (ret != 0) return(1);
+      ret = SUNDlsMat_denseGETRF(Pxy, NUM_SPECIES, NUM_SPECIES,
+                                 (data->pivot)[jx][jy]);
+      if (ret != 0) { return (1); }
 
     } /* end of jx loop */
 
   } /* end of jy loop */
 
-  return(0);
+  return (0);
 }
 
 /*
  * Preconditioner solve routine
  */
 
-static int PrecSolveBD(N_Vector cc, N_Vector cscale,
-                       N_Vector fval, N_Vector fscale,
-                       N_Vector vv, void *user_data)
+static int PrecSolveBD(N_Vector cc, N_Vector cscale, N_Vector fval,
+                       N_Vector fscale, N_Vector vv, void* user_data)
 {
-  realtype **Pxy, *vxy;
+  sunrealtype **Pxy, *vxy;
   sunindextype *piv, jx, jy;
   UserData data;
 
   data = (UserData)user_data;
 
-  for (jx=0; jx<MX; jx++) {
-
-    for (jy=0; jy<MY; jy++) {
-
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
       /* For each (jx,jy), solve a linear system of size NUM_SPECIES.
          vxy is the address of the corresponding portion of the vector vv;
          Pxy is the address of the corresponding block of the matrix P;
          piv is the address of the corresponding block of the array pivot. */
-      vxy = IJ_Vptr(vv,jx,jy);
+      vxy = IJ_Vptr(vv, jx, jy);
       Pxy = (data->P)[jx][jy];
       piv = (data->pivot)[jx][jy];
       SUNDlsMat_denseGETRS(Pxy, NUM_SPECIES, piv, vxy);
@@ -461,44 +461,49 @@ static int PrecSolveBD(N_Vector cc, N_Vector cscale,
 
   } /* end of jx loop */
 
-  return(0);
+  return (0);
 }
 
 /*
  * Interaction rate function routine
  */
 
-static void WebRate(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
-                    void *user_data)
+static void WebRate(sunrealtype xx, sunrealtype yy, sunrealtype* cxy,
+                    sunrealtype* ratesxy, void* user_data)
 {
   sunindextype i;
-  realtype fac;
+  sunrealtype fac;
   UserData data;
 
   data = (UserData)user_data;
 
-  for (i = 0; i<NUM_SPECIES; i++)
+  for (i = 0; i < NUM_SPECIES; i++)
+  {
     ratesxy[i] = DotProd(NUM_SPECIES, cxy, acoef[i]);
+  }
 
   fac = ONE + ALPHA * xx * yy;
 
   for (i = 0; i < NUM_SPECIES; i++)
-    ratesxy[i] = cxy[i] * ( bcoef[i] * fac + ratesxy[i] );
+  {
+    ratesxy[i] = cxy[i] * (bcoef[i] * fac + ratesxy[i]);
+  }
 }
 
 /*
- * Dot product routine for realtype arrays
+ * Dot product routine for sunrealtype arrays
  */
 
-static realtype DotProd(sunindextype size, realtype *x1, realtype *x2)
+static sunrealtype DotProd(sunindextype size, sunrealtype* x1, sunrealtype* x2)
 {
   sunindextype i;
-  realtype *xx1, *xx2, temp = ZERO;
+  sunrealtype *xx1, *xx2, temp = ZERO;
 
-  xx1 = x1; xx2 = x2;
-  for (i = 0; i < size; i++) temp += (*xx1++) * (*xx2++);
+  xx1 = x1;
+  xx2 = x2;
+  for (i = 0; i < size; i++) { temp += (*xx1++) * (*xx2++); }
 
-  return(temp);
+  return (temp);
 }
 
 /*
@@ -516,21 +521,23 @@ static UserData AllocUserData(void)
   int jx, jy;
   UserData data;
 
-  data = (UserData) malloc(sizeof *data);
+  data = (UserData)malloc(sizeof *data);
 
-  for (jx=0; jx < MX; jx++) {
-    for (jy=0; jy < MY; jy++) {
-      (data->P)[jx][jy] = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
+      (data->P)[jx][jy]     = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
       (data->pivot)[jx][jy] = SUNDlsMat_newIndexArray(NUM_SPECIES);
     }
   }
 
   acoef = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
-  bcoef = (realtype *)malloc(NUM_SPECIES * sizeof(realtype));
-  cox   = (realtype *)malloc(NUM_SPECIES * sizeof(realtype));
-  coy   = (realtype *)malloc(NUM_SPECIES * sizeof(realtype));
+  bcoef = (sunrealtype*)malloc(NUM_SPECIES * sizeof(sunrealtype));
+  cox   = (sunrealtype*)malloc(NUM_SPECIES * sizeof(sunrealtype));
+  coy   = (sunrealtype*)malloc(NUM_SPECIES * sizeof(sunrealtype));
 
-  return(data);
+  return (data);
 }
 
 /*
@@ -540,50 +547,53 @@ static UserData AllocUserData(void)
 static void InitUserData(UserData data)
 {
   sunindextype i, j, np;
-  realtype *a1,*a2, *a3, *a4, dx2, dy2;
+  sunrealtype *a1, *a2, *a3, *a4, dx2, dy2;
 
-  data->mx = MX;
-  data->my = MY;
-  data->ns = NUM_SPECIES;
-  data->np = NUM_SPECIES/2;
-  data->ax = AX;
-  data->ay = AY;
-  data->dx = (data->ax)/(MX-1);
-  data->dy = (data->ay)/(MY-1);
-  data->uround = UNIT_ROUNDOFF;
+  data->mx        = MX;
+  data->my        = MY;
+  data->ns        = NUM_SPECIES;
+  data->np        = NUM_SPECIES / 2;
+  data->ax        = AX;
+  data->ay        = AY;
+  data->dx        = (data->ax) / (MX - 1);
+  data->dy        = (data->ay) / (MY - 1);
+  data->uround    = SUN_UNIT_ROUNDOFF;
   data->sqruround = SUNRsqrt(data->uround);
 
   /* Set up the coefficients a and b plus others found in the equations */
   np = data->np;
 
-  dx2=(data->dx)*(data->dx); dy2=(data->dy)*(data->dy);
+  dx2 = (data->dx) * (data->dx);
+  dy2 = (data->dy) * (data->dy);
 
-  for (i = 0; i < np; i++) {
-    a1= &(acoef[i][np]);
-    a2= &(acoef[i+np][0]);
-    a3= &(acoef[i][0]);
-    a4= &(acoef[i+np][np]);
+  for (i = 0; i < np; i++)
+  {
+    a1 = &(acoef[i][np]);
+    a2 = &(acoef[i + np][0]);
+    a3 = &(acoef[i][0]);
+    a4 = &(acoef[i + np][np]);
 
     /*  Fill in the portion of acoef in the four quadrants, row by row */
-    for (j = 0; j < np; j++) {
-      *a1++ =  -GG;
-      *a2++ =   EE;
+    for (j = 0; j < np; j++)
+    {
+      *a1++ = -GG;
+      *a2++ = EE;
       *a3++ = ZERO;
       *a4++ = ZERO;
     }
 
     /* and then change the diagonal elements of acoef to -AA */
-    acoef[i][i]=-AA;
-    acoef[i+np][i+np] = -AA;
+    acoef[i][i]           = -AA;
+    acoef[i + np][i + np] = -AA;
 
-    bcoef[i] = BB;
-    bcoef[i+np] = -BB;
+    bcoef[i]      = BB;
+    bcoef[i + np] = -BB;
 
-    cox[i]=DPREY/dx2;
-    cox[i+np]=DPRED/dx2;
+    cox[i]      = DPREY / dx2;
+    cox[i + np] = DPRED / dx2;
 
-    coy[i]=DPREY/dy2;
-    coy[i+np]=DPRED/dy2;
+    coy[i]      = DPREY / dy2;
+    coy[i + np] = DPRED / dy2;
   }
 }
 
@@ -595,8 +605,10 @@ static void FreeUserData(UserData data)
 {
   int jx, jy;
 
-  for (jx=0; jx < MX; jx++) {
-    for (jy=0; jy < MY; jy++) {
+  for (jx = 0; jx < MX; jx++)
+  {
+    for (jy = 0; jy < MY; jy++)
+    {
       SUNDlsMat_destroyMat((data->P)[jx][jy]);
       SUNDlsMat_destroyArray((data->pivot)[jx][jy]);
     }
@@ -617,25 +629,30 @@ static void FreeUserData(UserData data)
 static void SetInitialProfiles(N_Vector cc, N_Vector sc)
 {
   int i, jx, jy;
-  realtype *cloc, *sloc;
-  realtype  ctemp[NUM_SPECIES], stemp[NUM_SPECIES];
+  sunrealtype *cloc, *sloc;
+  sunrealtype ctemp[NUM_SPECIES], stemp[NUM_SPECIES];
 
   /* Initialize arrays ctemp and stemp used in the loading process */
-  for (i = 0; i < NUM_SPECIES/2; i++) {
+  for (i = 0; i < NUM_SPECIES / 2; i++)
+  {
     ctemp[i] = PREYIN;
     stemp[i] = ONE;
   }
-  for (i = NUM_SPECIES/2; i < NUM_SPECIES; i++) {
+  for (i = NUM_SPECIES / 2; i < NUM_SPECIES; i++)
+  {
     ctemp[i] = PREDIN;
-    stemp[i] = RCONST(0.00001);
+    stemp[i] = SUN_RCONST(0.00001);
   }
 
   /* Load initial profiles into cc and sc vector from ctemp and stemp. */
-  for (jy = 0; jy < MY; jy++) {
-    for (jx = 0; jx < MX; jx++) {
-      cloc = IJ_Vptr(cc,jx,jy);
-      sloc = IJ_Vptr(sc,jx,jy);
-      for (i = 0; i < NUM_SPECIES; i++) {
+  for (jy = 0; jy < MY; jy++)
+  {
+    for (jx = 0; jx < MX; jx++)
+    {
+      cloc = IJ_Vptr(cc, jx, jy);
+      sloc = IJ_Vptr(sc, jx, jy);
+      for (i = 0; i < NUM_SPECIES; i++)
+      {
         cloc[i] = ctemp[i];
         sloc[i] = stemp[i];
       }
@@ -648,41 +665,36 @@ static void SetInitialProfiles(N_Vector cc, N_Vector sc)
  */
 
 static void PrintHeader(int globalstrategy, int maxl, int maxlrst,
-                        realtype fnormtol, realtype scsteptol)
+                        sunrealtype fnormtol, sunrealtype scsteptol)
 {
   printf("\nPredator-prey test problem --  KINSol (serial version)\n\n");
   printf("Mesh dimensions = %d X %d\n", MX, MY);
   printf("Number of species = %d\n", NUM_SPECIES);
   printf("Total system size = %d\n\n", NEQ);
-  printf("Flag globalstrategy = %d (0 = None, 1 = Linesearch)\n",
-         globalstrategy);
-  printf("Linear solver is SPGMR with maxl = %d, maxlrst = %d\n",
-         maxl, maxlrst);
+  printf("Flag globalstrategy = %d (0 = None, 1 = Linesearch)\n", globalstrategy);
+  printf("Linear solver is SPGMR with maxl = %d, maxlrst = %d\n", maxl, maxlrst);
   printf("Preconditioning uses interaction-only block-diagonal matrix\n");
   printf("Positivity constraints imposed on all components \n");
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-  printf("Tolerance parameters:  fnormtol = %Lg   scsteptol = %Lg\n",
-         fnormtol, scsteptol);
+  printf("Tolerance parameters:  fnormtol = %Lg   scsteptol = %Lg\n", fnormtol,
+         scsteptol);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("Tolerance parameters:  fnormtol = %g   scsteptol = %g\n",
-         fnormtol, scsteptol);
+  printf("Tolerance parameters:  fnormtol = %g   scsteptol = %g\n", fnormtol,
+         scsteptol);
 #else
-  printf("Tolerance parameters:  fnormtol = %g   scsteptol = %g\n",
-         fnormtol, scsteptol);
+  printf("Tolerance parameters:  fnormtol = %g   scsteptol = %g\n", fnormtol,
+         scsteptol);
 #endif
 
   printf("\nInitial profile of concentration\n");
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-  printf("At all mesh points:  %Lg %Lg %Lg   %Lg %Lg %Lg\n",
-         PREYIN, PREYIN, PREYIN,
-         PREDIN, PREDIN, PREDIN);
+  printf("At all mesh points:  %Lg %Lg %Lg   %Lg %Lg %Lg\n", PREYIN, PREYIN,
+         PREYIN, PREDIN, PREDIN, PREDIN);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-  printf("At all mesh points:  %g %g %g   %g %g %g\n",
-         PREYIN, PREYIN, PREYIN,
+  printf("At all mesh points:  %g %g %g   %g %g %g\n", PREYIN, PREYIN, PREYIN,
          PREDIN, PREDIN, PREDIN);
 #else
-  printf("At all mesh points:  %g %g %g   %g %g %g\n",
-         PREYIN, PREYIN, PREYIN,
+  printf("At all mesh points:  %g %g %g   %g %g %g\n", PREYIN, PREYIN, PREYIN,
          PREDIN, PREDIN, PREDIN);
 #endif
 }
@@ -694,37 +706,41 @@ static void PrintHeader(int globalstrategy, int maxl, int maxlrst,
 static void PrintOutput(N_Vector cc)
 {
   int is, jx, jy;
-  realtype *ct;
+  sunrealtype* ct;
 
-  jy = 0; jx = 0;
-  ct = IJ_Vptr(cc,jx,jy);
+  jy = 0;
+  jx = 0;
+  ct = IJ_Vptr(cc, jx, jy);
   printf("\nAt bottom left:");
 
   /* Print out lines with up to 6 values per line */
-  for (is = 0; is < NUM_SPECIES; is++){
-    if ((is%6)*6 == is) printf("\n");
+  for (is = 0; is < NUM_SPECIES; is++)
+  {
+    if ((is % 6) * 6 == is) { printf("\n"); }
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-    printf(" %Lg",ct[is]);
+    printf(" %Lg", ct[is]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf(" %g",ct[is]);
+    printf(" %g", ct[is]);
 #else
-    printf(" %g",ct[is]);
+    printf(" %g", ct[is]);
 #endif
   }
 
-  jy = MY-1; jx = MX-1;
-  ct = IJ_Vptr(cc,jx,jy);
+  jy = MY - 1;
+  jx = MX - 1;
+  ct = IJ_Vptr(cc, jx, jy);
   printf("\n\nAt top right:");
 
   /* Print out lines with up to 6 values per line */
-  for (is = 0; is < NUM_SPECIES; is++) {
-    if ((is%6)*6 == is) printf("\n");
+  for (is = 0; is < NUM_SPECIES; is++)
+  {
+    if ((is % 6) * 6 == is) { printf("\n"); }
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-    printf(" %Lg",ct[is]);
+    printf(" %Lg", ct[is]);
 #elif defined(SUNDIALS_DOUBLE_PRECISION)
-    printf(" %g",ct[is]);
+    printf(" %g", ct[is]);
 #else
-    printf(" %g",ct[is]);
+    printf(" %g", ct[is]);
 #endif
   }
   printf("\n\n");
@@ -734,7 +750,7 @@ static void PrintOutput(N_Vector cc)
  * Print final statistics contained in iopt
  */
 
-static void PrintFinalStats(void *kmem)
+static void PrintFinalStats(void* kmem)
 {
   long int nni, nfe, nli, npe, nps, ncfl, nfeSG;
   int retval;
@@ -758,7 +774,6 @@ static void PrintFinalStats(void *kmem)
   printf("nni    = %5ld    nli   = %5ld\n", nni, nli);
   printf("nfe    = %5ld    nfeSG = %5ld\n", nfe, nfeSG);
   printf("nps    = %5ld    npe   = %5ld     ncfl  = %5ld\n", nps, npe, ncfl);
-
 }
 
 /*
@@ -771,36 +786,37 @@ static void PrintFinalStats(void *kmem)
  *             NULL pointer
  */
 
-static int check_retval(void *retvalvalue, const char *funcname, int opt)
+static int check_retval(void* retvalvalue, const char* funcname, int opt)
 {
-  int *errretval;
+  int* errretval;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && retvalvalue == NULL) {
-    fprintf(stderr,
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
-	    funcname);
-    return(1);
+  if (opt == 0 && retvalvalue == NULL)
+  {
+    fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
+            funcname);
+    return (1);
   }
 
   /* Check if retval < 0 */
-  else if (opt == 1) {
-    errretval = (int *) retvalvalue;
-    if (*errretval < 0) {
-      fprintf(stderr,
-              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
-	      funcname, *errretval);
-      return(1);
+  else if (opt == 1)
+  {
+    errretval = (int*)retvalvalue;
+    if (*errretval < 0)
+    {
+      fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+              funcname, *errretval);
+      return (1);
     }
   }
 
   /* Check if function returned NULL pointer - no memory allocated */
-  else if (opt == 2 && retvalvalue == NULL) {
-    fprintf(stderr,
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
-	    funcname);
-    return(1);
+  else if (opt == 2 && retvalvalue == NULL)
+  {
+    fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
+            funcname);
+    return (1);
   }
 
-  return(0);
+  return (0);
 }
